==> netdata-v2.3.2.tar.gz: netdata-v2.3.2/docs/netdata-cloud/versions.md <==
# Netdata Cloud Versions

Netdata Cloud is available in two versions:

| Version                | Description                                                                                                                                                                                                                     |
|:-----------------------|:--------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------|
| **Cloud Service**      | The fully-managed service hosted at [app.netdata.cloud](https://app.netdata.cloud). [Connect](/src/claim/README.md) your Agents to access comprehensive infrastructure monitoring, real-time dashboards, and advanced features. |
| **Enterprise On-Prem** | A self-hosted version of Netdata Cloud for businesses requiring complete control over their monitoring infrastructure. Includes all features of our Cloud offering, deployed within your own environment.                       |

Visit our [Pricing](https://www.netdata.cloud/pricing/) page to compare features and options.

## Using Netdata Cloud Service

1. [Create an account](https://app.netdata.cloud) on Netdata Cloud.
2. Follow the provided setup instructions to install and connect Agents to your Space automatically

## Installing On-Prem

To learn more about installing Netdata Cloud in your own infrastructure:

1. Review the [Architecture Diagram](/docs/netdata-cloud/netdata-cloud-on-prem/README.md) to understand the system components.
2. Follow the [Deployment Guide](/docs/netdata-cloud/netdata-cloud-on-prem/installation.md) for detailed installation instructions

==> netdata-2.5.3.tar.gz: netdata-v2.5.3/docs/netdata-cloud/versions.md <==
# Netdata Cloud Versions

Netdata Cloud is available in two versions:

| Version                | Description                                                                                                                                                                                                                     |
|:-----------------------|:--------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------|
| **Cloud Service**      | The fully-managed service hosted at [app.netdata.cloud](https://app.netdata.cloud). [Connect](/src/claim/README.md) your Agents to access comprehensive infrastructure monitoring, real-time dashboards, and advanced features. |
| **Enterprise On-Prem** | A self-hosted version of Netdata Cloud for businesses requiring complete control over their monitoring infrastructure. Includes all features of our Cloud offering, deployed within your own environment.                       |

Visit our [Pricing](https://www.netdata.cloud/pricing/) page to compare features and options.

## Using Netdata Cloud Service

1. [Create an account](https://app.netdata.cloud) on Netdata Cloud.
2. Follow the provided setup instructions to install and connect Agents to your Space automatically

## Installing On-Prem

To learn more about installing Netdata Cloud in your own infrastructure:

1. Review the [Architecture Diagram](https://github.com/netdata/netdata-cloud-onprem/blob/master/docs/learn.netdata.cloud/README.md) to understand the system components.
2. Follow the [Deployment Guide](https://github.com/netdata/netdata-cloud-onprem/blob/master/docs/learn.netdata.cloud/installation.md) for detailed installation instructions
